==> bugscan_x-1.3.6b2-py3-none-any.whl: bugscanx/modules/scanners_pro/scanners/ping.py <==
import socket
from .base import BaseScanner


class PingScanner(BaseScanner):
    def __init__(
        self,
        host_list=None,
        port_list=None,
        is_cidr_input=False,
        task_list=None,
        threads=None
    ):
        super().__init__(task_list, threads)
        self.host_list = host_list or []
        self.port_list = port_list or []
        self.is_cidr_input = is_cidr_input

    def log_info(self, **kwargs):
        kwargs.setdefault('color', '')
        kwargs.setdefault('host', '')
        kwargs.setdefault('ip', '')
        kwargs.setdefault('port', '')

        if self.is_cidr_input:
            messages = [
                self.colorize('{port:<6}', 'CYAN'),
                self.colorize('{host}', 'LGRAY'),
            ]
        else:
            messages = [
                self.colorize('{port:<6}', 'CYAN'),
                self.colorize('{ip:<15}', 'YELLOW'),
                self.colorize('{host}', 'LGRAY'),
            ]

        super().log('  '.join(messages).format(**kwargs))

    def get_task_list(self):
        for host in self.filter_list(self.host_list):
            for port in self.filter_list(self.port_list):
                yield {
                    'host': host,
                    'port': port,
                }

    def init(self):
        super().init()
        if self.is_cidr_input:
            self.log_info(port='Port', host='Host')
            self.log_info(port='----', host='----')
        else:
            self.log_info(port='Port', ip='IP', host='Host')
            self.log_info(port='----', ip='--', host='----')

    def resolve_ip(self, host):
        try:
            return socket.gethostbyname(host)
        except Exception:
            return "Unknown"

    def task(self, payload):
        host = payload['host']
        port = payload['port']

        if not host:
            return
        
        try:
            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
                sock.settimeout(2)
                result = sock.connect_ex((host, int(port)))

            if result == 0:
                ip = self.resolve_ip(host)
                data = {
                    'host': host,
                    'port': port,
                    'ip': ip
                }
                self.task_success(data)
                self.log_info(**data)

        except Exception:
            pass

        self.log_replace(f"{host}:{port}")

    def complete(self):
        self.log_replace(self.colorize("Scan completed", "GREEN"))
        super().complete()

==> bugscan_x-1.4.0-py3-none-any.whl: bugscanx/modules/scanners_pro/scanners/ping.py <==
import socket
from .base import BaseScanner


class PingScanner(BaseScanner):
    def __init__(
        self,
        host_list=None,
        port_list=None,
        is_cidr_input=False,
    ):
        super().__init__()
        self.host_list = host_list or []
        self.port_list = port_list or []
        self.is_cidr_input = is_cidr_input

    def log_info(self, **kwargs):
        if self.is_cidr_input:
            log_parts = [
                self.colorize('{port:<6}', 'CYAN'),
                self.colorize('{host}', 'LGRAY'),
            ]
        else:
            log_parts = [
                self.logger.colorize('{port:<6}', 'CYAN'),
                self.logger.colorize('{ip:<15}', 'YELLOW'),
                self.logger.colorize('{host}', 'LGRAY'),
            ]

        self.logger.log('  '.join(log_parts).format(**kwargs))

    def generate_tasks(self):
        for host in self.filter_list(self.host_list):
            for port in self.filter_list(self.port_list):
                yield {
                    'host': host,
                    'port': port,
                }

    def init(self):
        if self.is_cidr_input:
            self.log_info(port='Port', host='Host')
            self.log_info(port='----', host='----')
        else:
            self.log_info(port='Port', ip='IP', host='Host')
            self.log_info(port='----', ip='--', host='----')

    def resolve_ip(self, host):
        try:
            return socket.gethostbyname(host)
        except Exception:
            return "Unknown"

    def task(self, payload):
        host = payload['host']
        port = payload['port']

        if not host:
            return
        
        try:
            with socket.socket(socket.AF_INET, socket.SOCK_STREAM) as sock:
                sock.settimeout(2)
                result = sock.connect_ex((host, int(port)))

            if result == 0:
                ip = self.resolve_ip(host)
                data = {
                    'host': host,
                    'port': port,
                    'ip': ip
                }
                self.success(data)
                self.log_info(**data)

        except Exception:
            pass

        self.log_progress(f"{host}:{port}")

    def complete(self):
        self.log_progress(self.logger.colorize("Scan completed", "GREEN"))
